/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.core.functions;

import pl.chyla.wyjec.core.BaseTestFunction;
import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.core.Type;
import pl.chyla.wyjec.core.Value;


/**
 * Base class for classes testing date functions (functions returning date values).
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public abstract class BaseTestDateFunction extends BaseTestFunction {

    /**
     * Instance of date function used for evaluation during testing.
     */
    private final DateFunction function;

    /**
     * Constructs date function test using given function instance.
     *
     * @param function function to use for evaluation during testing
     */
    protected BaseTestDateFunction(DateFunction function) {
        this.function = function;
    }

    /**
     * {@inheritDoc}
     */
    protected final Function getFunction() {
        return function;
    }

    /**
     * Tests whether the function declares the appropriate result type.
     */
    public void testReturnType() {
        assertSame(function.getResultType(), Type.DATE);
    }

    /**
     * Evaluates function associated with the test, using parameters from given array.
     *
     * @param params parameters to pass to the function
     * @return function's result
     */
    protected final long evaluateFunction(Value[] params) {
        return rawEvaluateFunction(params).getDate();
    }

    /**
     * Evaluates function associated with the test using given parameters and checks if the
     * result of evaluation is equal to given expected value. If these values are different,
     * the method fails with assertion exception.
     *
     * @param params parameters to pass to the function
     * @param expResult expected result of function evaluation
     */
    protected final void checkFunctionResult(Value[] params, long expResult) {
        assertEquals(evaluateFunction(params), expResult);
    }

}
