/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.evaluator;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.TestValue;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.optparameters.IntegerOptParameters;
import pl.chyla.wyjec.core.parameters.IntegerParameter;


/**
 * Test function supporting lazy evaluation of its parameters, using the first parameter as the
 * index in the sequence of the rest of parameters and returning the parameter at given index.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public class FnChoose extends IntegerFunction {

    /**
     * Index (0-based) of a value to return
     */
    private static final IntegerParameter pValueIndex = new IntegerParameter();

    /**
     * Integer parameters to choose the function's result from
     */
    private static final IntegerOptParameters pOptValues = new IntegerOptParameters();

    /**
     * The function's signature
     */
    private static final FunctionSignature signature =
        new FunctionSignature(new Parameter[] {pValueIndex}, pOptValues, true);

    /**
     * {@inheritDoc}
     */
    public FunctionSignature getSignature() {
        return signature;
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return "choose";
    }

    /**
     * {@inheritDoc}
     */
    protected long execute() {
        int index = (int) getParameter(pValueIndex);
        return getParameter(pOptValues, index);
    }

    /**
     * Returns the result of function evaluation, operating directly on {@link Value} instances.
     *
     * @param parameters parameters used for evaluation
     * @return evaluation result
     */
    public static Value testExecute(Value[] parameters) {
        int index = (int) parameters[0].getInteger();
        return TestValue.makeInteger(parameters[index + 1].getInteger());
    }

}
