/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.evaluator;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.functions.IntegerFunction;


/**
 * Test function always returning integer <code>0</code> and setting an internal flag every time
 * it's evaluated. The function supports reading and resetting the flag.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public class FnFlag extends IntegerFunction {

    /**
     * Boolean flag informing whether evaluation of this function has been performed.
     */
    private boolean evaluated;

    /**
     * {@inheritDoc}
     */
    public FunctionSignature getSignature() {
        return FunctionSignature.SIGNATURE_NO_PARAMETERS;
    }

    /**
     * {@inheritDoc}
     */
    public String getName() {
        return "flag";
    }
    /**
     * {@inheritDoc}
     */
    protected long execute() {
        evaluated = true;
        return 0L;
    }

    /**
     * Returns boolean flag informing whether evaluation of this function has been performed.
     *
     * @return
     *     <code>true</code> if this function has been evaluated since its construction or the
     *     last {@link #resetEvaluated()} method call, <code>false</code> otherwise
     */
    public boolean isEvaluated() {
        return evaluated;
    }

    /**
     * Resets internal flag informing whether this function has been evaluated.
     */
    public void resetEvaluated() {
        evaluated = false;
    }

}
