/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.extfuncs.langfuncs;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnPluralEN} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnPluralEN extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnPluralEN() {
        super(new FnPluralEN());
    }

    /**
     * Evaluates {@link FnPluralEN} function with given parameters using different variants of
     * <code>singular</code> and <code>plural</code> {@link pl.chyla.wyjec.utils.RawString}
     * equivalents and checks if the result is always equal to the expected result.
     *
     * @param numberParam value of <code>number</code> parameter to pass to the function
     * @param singularParam value of <code>singular</code> parameter to pass to the function
     * @param pluralParam value of <code>plural</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnPluralEN(
        long numberParam, String singularParam, String pluralParam, String expResult) {
        Value[] singularParamVariants = makeStringValueVariants(singularParam);
        Value[] pluralParamVariants = makeStringValueVariants(pluralParam);
        for (int i = 0; i < singularParamVariants.length; i++) {
            for (int j = 0; j < pluralParamVariants.length; j++) {
                checkFunctionResultVarSizes(
                    new Value[] {
                        makeIntegerValue(numberParam), singularParamVariants[i],
                        pluralParamVariants[j]},
                    expResult);
            }
        }
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFnPluralEN(0, "dog", "dogs", "dogs");
        checkFnPluralEN(1, "dog", "dogs", "dog");
        checkFnPluralEN(10, "cat", "cats", "cats");
        checkFnPluralEN(221, "cat", "cats", "cats");
    }

}
