/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.extfuncs.langfuncs;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnPluralPL} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnPluralPL extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnPluralPL() {
        super(new FnPluralPL());
    }

    /**
     * Evaluates {@link FnPluralPL} function with given parameters using different variants of
     * <code>singular</code> and <code>plural</code> {@link pl.chyla.wyjec.utils.RawString}
     * equivalents and checks if the result is always equal to the expected result.
     *
     * @param numberParam value of <code>number</code> parameter to pass to the function
     * @param singularParam value of <code>singular</code> parameter to pass to the function
     * @param pluralParam value of <code>plural</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnPluralPL(
        long numberParam, String singularParam, String plural1Param, String plural2Param,
        String expResult) {
        checkFunctionResultVarSizes(
            new Value[] {
                makeIntegerValue(numberParam), makeStringValue(singularParam),
                makeStringValue(plural1Param), makeStringValue(plural2Param)},
            expResult);
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFnPluralPL(0, "okno", "okna", "okien", "okien");
        checkFnPluralPL(1, "okno", "okna", "okien", "okno");
        checkFnPluralPL(2, "okno", "okna", "okien", "okna");
        checkFnPluralPL(4, "okno", "okna", "okien", "okna");
        checkFnPluralPL(11, "okno", "okna", "okien", "okien");
        checkFnPluralPL(12, "okno", "okna", "okien", "okien");
        checkFnPluralPL(15, "okno", "okna", "okien", "okien");
        checkFnPluralPL(22, "okno", "okna", "okien", "okna");
        checkFnPluralPL(25, "okno", "okna", "okien", "okien");
        checkFnPluralPL(1341, "okno", "okna", "okien", "okien");
        checkFnPluralPL(2, "miejsce", "miejsca", "miejsc", "miejsca");
        checkFnPluralPL(4, "miejsce", "miejsca", "miejsc", "miejsca");
        checkFnPluralPL(14, "miejsce", "miejsca", "miejsc", "miejsc");
    }

}
