/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.parser;


/**
 * Class describing expression tree.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class ExpressionTreeDescription {

    /**
     * Description of top-level atom in the expression.
     */
    private final AtomNodeDescription topAtom;

    /**
     * Constructs <code>ExpressionTreeDescription</code> instance, using given description of
     * top-level expression atom.
     *
     * @param topAtom description of top-level atom in the expression
     */
    public ExpressionTreeDescription(AtomNodeDescription topAtom) {
        this.topAtom = topAtom;
    }

    /**
     * Generates expression tree specified by this description object, together with the
     * expression's top-level node and its (direct and indirect) references.
     *
     * @param pool a pool used to generate instance of expression tree and all its nodes
     * @return expression tree described by this object
     */
    public ExpressionTree makeExpressionTree(ExprTreePool pool) {
        ExpressionTree exprTree = pool.getExpressionTree();
        exprTree.set(topAtom.makeAtomNode(pool));
        return exprTree;
    }

    /**
     * Informs whether this description matches given real expression tree. The operation is
     * performed by recursive checking if the appropriate descriptions of expression elements
     * match the actual expression tree nodes.
     *
     * @param exprTree expression tree to check this description against.
     * @return
     *     <code>true</code> if this description matches given expression tree,
     *     <code>false</code> otherwise
     */
    boolean isMatching(ExpressionTree exprTree) {
        return topAtom.isMatching(exprTree.getTopLevelAtom());
    }

}
