/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs;

import junit.framework.Test;
import junit.framework.TestSuite;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.TestFnDay;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.TestFnHour;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.TestFnMinute;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.TestFnMonth;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.TestFnSecond;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.TestFnYear;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnAdditionDays;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnAdditionHours;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnAdditionMinutes;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnAdditionSeconds;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnSubtractionDays;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnSubtractionHours;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnSubtractionMinutes;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.TestFnSubtractionSeconds;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.TestFnDateFromMilliseconds;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.TestFnDateFromYMD;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.TestFnDateFromYMDHMS;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.TestFnFormat;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.TestFnMidnight;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.TestFnStr;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.TestFnEqual;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.TestFnGreater;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.TestFnGreaterOrEqual;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.TestFnLess;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.TestFnLessOrEqual;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.TestFnIf;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.TestFnMax;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.TestFnMin;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.TestFnSelect;


/**
 * Tests for classes from "pl.chyla.wyjec.stdfuncs.datefuncs" package and its sub-packages.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class AllTestsDateFuncs extends TestSuite {

    /**
     * Builds test suite with all tests for standard Wyjec date functions.
     *
     * @return test suite with tests for classes from "datefuncs" package and its sub-packages.
     */
    public static Test suite() {
        TestSuite suite = new TestSuite();
        suite.addTestSuite(TestDateFunctions.class);
        suite.addTestSuite(TestFnDay.class);
        suite.addTestSuite(TestFnHour.class);
        suite.addTestSuite(TestFnMinute.class);
        suite.addTestSuite(TestFnMonth.class);
        suite.addTestSuite(TestFnSecond.class);
        suite.addTestSuite(TestFnYear.class);
        suite.addTestSuite(TestFnAdditionDays.class);
        suite.addTestSuite(TestFnAdditionHours.class);
        suite.addTestSuite(TestFnAdditionMinutes.class);
        suite.addTestSuite(TestFnAdditionSeconds.class);
        suite.addTestSuite(TestFnSubtractionDays.class);
        suite.addTestSuite(TestFnSubtractionHours.class);
        suite.addTestSuite(TestFnSubtractionMinutes.class);
        suite.addTestSuite(TestFnSubtractionSeconds.class);
        suite.addTestSuite(TestFnDateFromMilliseconds.class);
        suite.addTestSuite(TestFnDateFromYMD.class);
        suite.addTestSuite(TestFnDateFromYMDHMS.class);
        suite.addTestSuite(TestFnFormat.class);
        suite.addTestSuite(TestFnMidnight.class);
        suite.addTestSuite(TestFnStr.class);
        suite.addTestSuite(TestFnEqual.class);
        suite.addTestSuite(TestFnGreater.class);
        suite.addTestSuite(TestFnGreaterOrEqual.class);
        suite.addTestSuite(TestFnLess.class);
        suite.addTestSuite(TestFnLessOrEqual.class);
        suite.addTestSuite(TestFnIf.class);
        suite.addTestSuite(TestFnMax.class);
        suite.addTestSuite(TestFnMin.class);
        suite.addTestSuite(TestFnSelect.class);
        return suite;
    }

}
