/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.relations;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestBooleanFunction;


/**
 * Tests for {@link FnEqual} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnEqual extends BaseTestBooleanFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnEqual() {
        super(new FnEqual());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        Value aValue = makeDateValue(1970, 1, 1, 0, 0, 0);
        Value bValue = makeDateValue(1975, 4, 9, 16, 17, 18);
        Value cValue = makeDateValue(1977, 3, 9, 21, 0, 0);
        checkFunctionResultTrue(new Value[] {aValue});
        checkFunctionResultFalse(new Value[] {bValue, aValue});
        checkFunctionResultFalse(new Value[] {bValue, aValue, bValue});
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        Arrays.fill(params, bValue);
        checkFunctionResultTrue(params);
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = aValue;
        checkFunctionResultFalse(params);
        Arrays.fill(params, bValue);
        params[0] = cValue;
        checkFunctionResultFalse(params);
    }

}
