/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.selection;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestDateFunction;


/**
 * Tests for {@link FnMax} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnMax extends BaseTestDateFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnMax() {
        super(new FnMax());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        Value aValue = makeDateValue(1970, 1, 1, 0, 0, 0);
        Value bValue = makeDateValue(1975, 4, 9, 15, 16, 17);
        Value cValue = makeDateValue(1977, 3, 9, 21, 0, 0);
        Value dValue = makeDateValue(1979, 9, 11, 16, 17, 18);
        checkFunctionResult(
            new Value[] {cValue},
            cValue.getDate());
        checkFunctionResult(
            new Value[] {bValue, cValue},
            cValue.getDate());
        checkFunctionResult(
            new Value[] {aValue, bValue, cValue, dValue},
            dValue.getDate());
        checkFunctionResult(
            new Value[] {bValue, cValue, cValue},
            cValue.getDate());
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        Arrays.fill(params, cValue);
        checkFunctionResult(params, cValue.getDate());
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = dValue;
        checkFunctionResult(params, dValue.getDate());
        Arrays.fill(params, cValue);
        params[0] = dValue;
        checkFunctionResult(params, dValue.getDate());
    }

}
