/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.basic;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnStr} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnStr extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnStr() {
        super(new FnStr());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(0.0)},
            "0.0");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(5.0)},
            "5.0");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(-5.0)},
            "-5.0");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(123000000.12)},
            "123000000.12");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(-123000000.12)},
            "-123000000.12");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(12.34e25)},
            "1.234e26");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(-98.76e25)},
            "-9.876e26");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(-98.76e-25)},
            "-9.876e-24");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(Double.NEGATIVE_INFINITY)},
            "-inf");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(Double.POSITIVE_INFINITY)},
            "inf");
        checkFunctionResultVarSizes(
            new Value[] {makeFloatValue(Double.NaN)},
            "NaN");
    }

}
