/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.relations;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestBooleanFunction;


/**
 * Tests for {@link FnEqual} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnEqual extends BaseTestBooleanFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnEqual() {
        super(new FnEqual());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        double aValue = -0.756;
        double bValue = 7.5;
        double cValue = 23.45e23;
        checkFunctionResultTrue(new Value[] {makeFloatValue(cValue)});
        checkFunctionResultTrue(new Value[] {makeFloatValue(Double.POSITIVE_INFINITY)});
        checkFunctionResultFalse(new Value[] {makeFloatValue(aValue), makeFloatValue(cValue)});
        checkFunctionResultTrue(
            new Value[] {
                makeFloatValue(Double.POSITIVE_INFINITY),
                makeFloatValue(Double.POSITIVE_INFINITY)});
        checkFunctionResultFalse(
            new Value[] {
                makeFloatValue(aValue), makeFloatValue(cValue), makeFloatValue(aValue)});
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        Arrays.fill(params, makeFloatValue(aValue));
        checkFunctionResultTrue(params);
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = makeFloatValue(cValue);
        checkFunctionResultFalse(params);
        Arrays.fill(params, makeFloatValue(aValue));
        params[0] = makeFloatValue(bValue);
        checkFunctionResultFalse(params);
        checkFunctionResultFalse(new Value[] {
            makeFloatValue(aValue), makeFloatValue(Double.NaN), makeFloatValue(bValue)});
        checkFunctionResultFalse(new Value[] {
            makeFloatValue(Double.NaN), makeFloatValue(Double.NaN)});
        checkFunctionResultFalse(new Value[] {makeFloatValue(Double.NaN)});
    }

}
