/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.selection;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestFloatFunction;


/**
 * Tests for {@link FnMin} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnMin extends BaseTestFloatFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnMin() {
        super(new FnMin());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        double aValue = Double.NEGATIVE_INFINITY;
        double bValue = -19.3;
        double cValue = 975.31e18;
        double dValue = Double.POSITIVE_INFINITY;
        checkFunctionResult(
            new Value[] {makeFloatValue(dValue)},
            dValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue)},
            aValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(bValue)},
            bValue);
        checkFunctionResult(
            new Value[] {makeFloatValue(aValue), makeFloatValue(bValue)},
            aValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(bValue), makeFloatValue(aValue), makeFloatValue(cValue)},
            aValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(cValue), makeFloatValue(bValue), makeFloatValue(bValue)},
            bValue);
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        Arrays.fill(params, makeFloatValue(cValue));
        checkFunctionResult(params, cValue);
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = makeFloatValue(bValue);
        checkFunctionResult(params, bValue);
        Arrays.fill(params, makeFloatValue(cValue));
        params[0] = makeFloatValue(bValue);
        checkFunctionResult(params, bValue);
        checkFunctionResult(
            new Value[] {
                makeFloatValue(cValue), makeFloatValue(Double.NaN), makeFloatValue(dValue)},
            Double.NaN);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.NaN)},
            Double.NaN);
    }

}
