/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs;

import junit.framework.Test;
import junit.framework.TestSuite;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnAbs;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnAddition;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnDivision;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnDivisionWithDefault;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnModulo;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnModuloWithDefault;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnMultiplication;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnNegation;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.TestFnSubtraction;
import pl.chyla.wyjec.stdfuncs.integerfuncs.basic.TestFnIntFromDate;
import pl.chyla.wyjec.stdfuncs.integerfuncs.basic.TestFnIntFromFloat;
import pl.chyla.wyjec.stdfuncs.integerfuncs.basic.TestFnStr;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.TestFnEqual;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.TestFnGreater;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.TestFnGreaterOrEqual;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.TestFnLess;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.TestFnLessOrEqual;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.TestFnIf;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.TestFnMax;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.TestFnMin;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.TestFnSelect;


/**
 * Tests for classes from "pl.chyla.wyjec.stdfuncs.integerfuncs" package and its sub-packages.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class AllTestsIntegerFuncs extends TestSuite {

    /**
     * Builds test suite with all tests for standard Wyjec integer functions.
     *
     * @return
     *     test suite with tests for classes from "integerfuncs" package and its sub-packages.
     */
    public static Test suite() {
        TestSuite suite = new TestSuite();
        suite.addTestSuite(TestIntegerFunctions.class);
        suite.addTestSuite(TestFnAbs.class);
        suite.addTestSuite(TestFnAddition.class);
        suite.addTestSuite(TestFnDivision.class);
        suite.addTestSuite(TestFnDivisionWithDefault.class);
        suite.addTestSuite(TestFnModulo.class);
        suite.addTestSuite(TestFnModuloWithDefault.class);
        suite.addTestSuite(TestFnMultiplication.class);
        suite.addTestSuite(TestFnNegation.class);
        suite.addTestSuite(TestFnSubtraction.class);
        suite.addTestSuite(TestFnIntFromDate.class);
        suite.addTestSuite(TestFnIntFromFloat.class);
        suite.addTestSuite(TestFnStr.class);
        suite.addTestSuite(TestFnEqual.class);
        suite.addTestSuite(TestFnGreater.class);
        suite.addTestSuite(TestFnGreaterOrEqual.class);
        suite.addTestSuite(TestFnLess.class);
        suite.addTestSuite(TestFnLessOrEqual.class);
        suite.addTestSuite(TestFnIf.class);
        suite.addTestSuite(TestFnMax.class);
        suite.addTestSuite(TestFnMin.class);
        suite.addTestSuite(TestFnSelect.class);
        return suite;
    }

}
