/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.basic;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestIntegerFunction;


/**
 * Tests for {@link FnIntFromFloat} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnIntFromFloat extends BaseTestIntegerFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnIntFromFloat() {
        super(new FnIntFromFloat());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFunctionResult(
            new Value[] {makeFloatValue(0.0)},
            0L);
        checkFunctionResult(
            new Value[] {makeFloatValue(0.5)},
            0L);
        checkFunctionResult(
            new Value[] {makeFloatValue(-0.5)},
            0L);
        checkFunctionResult(
            new Value[] {makeFloatValue(1234567890123456.789)},
            1234567890123456L);
        checkFunctionResult(
            new Value[] {makeFloatValue(-1234567890123456.789)},
            -1234567890123456L);
        checkFunctionResult(
            new Value[] {makeFloatValue(12345.67e123)},
            9223372036854775807L);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.POSITIVE_INFINITY)},
            9223372036854775807L);
        checkFunctionResult(
            new Value[] {makeFloatValue(-12345.67e123)},
            -9223372036854775808L);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.NEGATIVE_INFINITY)},
            -9223372036854775808L);
        checkFunctionResult(
            new Value[] {makeFloatValue(Double.NaN)},
            0L);
        checkFunctionResult(
            new Value[] {makeFloatValue(-0.000012345)},
            0L);
    }

}
