/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestIntegerFunction;


/**
 * Tests for {@link FnFind} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnFind extends BaseTestIntegerFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnFind() {
        super(new FnFind());
    }

    /**
     * Evaluates {@link FnFind} function with given parameters using different variants of their
     * {@link pl.chyla.wyjec.utils.RawString} equivalents and checks if the result is always
     * equal to the expected result.
     *
     * @param valueParam value of <code>value</code> parameter to pass to the function
     * @param subParam value of <code>sub</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnFind(String valueParam, String subParam, long expResult) {
        Value[] valueParamVariants = makeStringValueVariants(valueParam);
        Value[] subParamVariants = makeStringValueVariants(subParam);
        for (int i = 0; i < valueParamVariants.length; i++) {
            for (int j = 0; j < subParamVariants.length; j++) {
                checkFunctionResult(
                    new Value[] {valueParamVariants[i], subParamVariants[j]},
                    expResult);
            }
        }
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        String str = "abcde Fgh kl m";
        checkFnFind(str, "", 0);
        checkFnFind(str, "abc", 0);
        checkFnFind(str, "abd", -1);
        checkFnFind(str, "de F", 3);
        checkFnFind(str, "kl m", 10);
        checkFnFind(str, "kl mn", -1);
        checkFnFind("", "", 0);
        checkFnFind("", "a", -1);
    }

}
