/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestIntegerFunction;


/**
 * Tests for {@link FnLen} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnLen extends BaseTestIntegerFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnLen() {
        super(new FnLen());
    }

    /**
     * Evaluates {@link FnLen} function with given parameter using different variants of its
     * {@link pl.chyla.wyjec.utils.RawString} equivalent and checks if the result is always
     * equal to the expected result.
     *
     * @param valueParam value of <code>value</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnLen(String valueParam, long expResult) {
        Value[] valueParamVariants = makeStringValueVariants(valueParam);
        for (int i = 0; i < valueParamVariants.length; i++) {
            checkFunctionResult(
                new Value[] {valueParamVariants[i]},
                expResult);
        }
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFnLen("", 0);
        checkFnLen("z", 1);
        checkFnLen("abc", 3);
        checkFnLen("abc defg ", 9);
    }

}
