/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnRStrip} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnRStrip extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnRStrip() {
        super(new FnRStrip());
    }

    /**
     * Evaluates {@link FnRStrip} function with given parameters using different variants of
     * {@link pl.chyla.wyjec.utils.RawString} equivalents for <code>value</code> and
     * <code>stripChars</code> parameters and checks if the result is always equal to the
     * expected result.
     *
     * @param valueParam value of <code>value</code> parameter to pass to the function
     * @param stripCharsParam value of <code>stripChars</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnRStrip(String valueParam, String stripCharsParam, String expResult) {
        Value[] valueParamVariants = makeStringValueVariants(valueParam);
        Value[] stripCharsParamVariants = makeStringValueVariants(stripCharsParam);
        for (int i = 0; i < valueParamVariants.length; i++) {
            for (int j = 0; j < stripCharsParamVariants.length; j++) {
                Value[] params = {valueParamVariants[i], stripCharsParamVariants[j]};
                checkFunctionResultVarSizes(params, expResult);
            }
        }
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFnRStrip("", "", "");
        checkFnRStrip("", " .", "");
        checkFnRStrip("  abc  ", " ", "  abc");
        checkFnRStrip(".,..,,abc.,..,,-", ".,", ".,..,,abc.,..,,-");
        checkFnRStrip(".,..,,abc.,..,,", ".,", ".,..,,abc");
        checkFnRStrip(".,..,,abc., ..,,", ".,", ".,..,,abc., ");
        checkFnRStrip("1abc0def005295723462", "0123456789", "1abc0def");
    }

}
