/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnReplace} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnReplace extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnReplace() {
        super(new FnReplace());
    }

    /**
     * Evaluates {@link FnReplace} function with given parameters using different variants of
     * their {@link pl.chyla.wyjec.utils.RawString} equivalents and checks if the result is
     * always equal to the expected result.
     *
     * @param valueParam value of <code>value</code> parameter to pass to the function
     * @param oldSubParam value of <code>oldSub</code> parameter to pass to the function
     * @param newSubParam value of <code>newSub</code> parameter to pass to the function
     * @param expResult expected result of function evaluations
     */
    private void checkFnReplace(
        String valueParam, String oldSubParam, String newSubParam, String expResult) {
        Value[] valueParamVariants = makeStringValueVariants(valueParam);
        Value[] oldSubParamVariants = makeStringValueVariants(oldSubParam);
        Value[] newSubParamVariants = makeStringValueVariants(newSubParam);
        for (int i = 0; i < valueParamVariants.length; i++) {
            for (int j = 0; j < oldSubParamVariants.length; j++) {
                for (int k = 0; k < newSubParamVariants.length; k++) {
                    Value[] params = {
                        valueParamVariants[i], oldSubParamVariants[j], newSubParamVariants[k]};
                    checkFunctionResult(params, expResult);
                }
            }
        }
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        checkFnReplace("", "", "", "");
        checkFnReplace("", "a", "bc", "");
        checkFnReplace("blabla bla", "", "x", "blabla bla");
        checkFnReplace("blabla bla", "l", "", "baba ba");
        checkFnReplace("blabla bla", "l", "x", "bxabxa bxa");
        checkFnReplace("blabla bla", "a", "bcx", "blbcxblbcx blbcx");
        checkFnReplace("blabla bla", "bla", "", " ");
        checkFnReplace("blabla bla", "bla", "x", "xx x");
        checkFnReplace("blabla bla", "la", "wyjec", "bwyjecbwyjec bwyjec");
    }

}
