/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnSubStr} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnSubstr extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnSubstr() {
        super(new FnSubStr());
    }

    /**
     * Evaluates {@link FnSubStr} function with given parameters using different variants of
     * <code>string</code> parameter {@link pl.chyla.wyjec.utils.RawString} equivalent and
     * checks if the result is always equal to the expected result.
     *
     * @param valueParam value of <code>value</code> parameter to pass to the function
     * @param repetitionsParam
     *     value of <code>repetitions</code> parameter to pass to the function 
     * @param expResult expected result of function evaluations
     */
    private void checkFnSubStr(
        String valueParam, int subStartParam, int subEndParam, String expResult) {
        Value[] valueParamVariants = makeStringValueVariants(valueParam);
        for (int i = 0; i < valueParamVariants.length; i++) {
            Value[] params = new Value[] {
                valueParamVariants[i], makeIntegerValue(subStartParam),
                makeIntegerValue(subEndParam)};
            checkFunctionResultVarSizes(params, expResult);
        }
    }

    /**
     * Tests implementation of the function for empty string.
     */
    public void testEvaluateEmpty() {
        checkFnSubStr("", 0, 0, "");
        checkFnSubStr("", 0, 5, "");
        checkFnSubStr("", 0, -5, "");
        checkFnSubStr("", 5, 0, "");
        checkFnSubStr("", 5, 10, "");
        checkFnSubStr("", 5, -5, "");
        checkFnSubStr("", -5, 0, "");
        checkFnSubStr("", -5, 5, "");
        checkFnSubStr("", -5, -5, "");
    }

    /**
     * Tests implementation of the function for 1-character string.
     */
    public void testEvaluateOneChar() {
        checkFnSubStr("a", 0, 0, "");
        checkFnSubStr("a", 0, 1, "a");
        checkFnSubStr("a", 0, 10, "a");
        checkFnSubStr("a", 0, -5, "");
        checkFnSubStr("a", 1, 0, "");
        checkFnSubStr("a", 1, 1, "");
        checkFnSubStr("a", 1, 10, "");
        checkFnSubStr("a", 1, -5, "");
        checkFnSubStr("a", -1, 0, "");
        checkFnSubStr("a", -1, 1, "a");
        checkFnSubStr("a", -1, 10, "a");
        checkFnSubStr("a", -1, -5, "");
        checkFnSubStr("a", -5, 0, "");
        checkFnSubStr("a", -5, 1, "a");
        checkFnSubStr("a", -5, 10, "a");
        checkFnSubStr("a", -5, -5, "");
        checkFnSubStr("a", 5, 0, "");
        checkFnSubStr("a", 5, 1, "");
        checkFnSubStr("a", 5, 10, "");
        checkFnSubStr("a", 5, -5, "");
        checkFnSubStr("a", -10, 20, "a");
    }

    /**
     * Tests implementation of the function for multiple-characters string.
     */
    public void testEvaluateMultipleChars() {
        checkFnSubStr(" abcdef ", 0, 0, "");
        checkFnSubStr(" abcdef ", 0, 3, " ab");
        checkFnSubStr(" abcdef ", 0, 20, " abcdef ");
        checkFnSubStr(" abcdef ", 0, -5, "");
        checkFnSubStr(" abcdef ", 8, 0, "");
        checkFnSubStr(" abcdef ", 8, 3, "");
        checkFnSubStr(" abcdef ", 8, 20, "");
        checkFnSubStr(" abcdef ", 8, -5, "");
        checkFnSubStr(" abcdef ", 3, 0, "");
        checkFnSubStr(" abcdef ", 3, 4, "cdef");
        checkFnSubStr(" abcdef ", 3, 20, "cdef ");
        checkFnSubStr(" abcdef ", 3, -5, "");
        checkFnSubStr(" abcdef ", -3, 0, "");
        checkFnSubStr(" abcdef ", -3, 2, "ef");
        checkFnSubStr(" abcdef ", -3, 20, "ef ");
        checkFnSubStr(" abcdef ", -3, -5, "");
        checkFnSubStr(" abcdef ", -20, 0, "");
        checkFnSubStr(" abcdef ", -20, 3, " ab");
        checkFnSubStr(" abcdef ", -20, 20, " abcdef ");
        checkFnSubStr(" abcdef ", -20, -5, "");
        checkFnSubStr(" abcdef ", 20, 0, "");
        checkFnSubStr(" abcdef ", 20, 3, "");
        checkFnSubStr(" abcdef ", 20, 20, "");
        checkFnSubStr(" abcdef ", 20, -5, "");
        checkFnSubStr(" abcdef ", -10, 20, " abcdef ");
    }

}
