/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.selection;

import java.util.Arrays;
import pl.chyla.wyjec.core.Value;
import pl.chyla.wyjec.core.functions.BaseTestStringFunction;


/**
 * Tests for {@link FnSelect} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestFnSelect extends BaseTestStringFunction {

    /**
     * Constructs test instance with associated instance of the function.
     */
    public TestFnSelect() {
        super(new FnSelect());
    }

    /**
     * Tests implementation of the function.
     */
    public void testEvaluate() {
        String aValue = "a4";
        String bValue = "cde";
        String cValue = "fgh";
        String dValue = "ijk";
        checkFunctionResultVarSizes(
            new Value[] {makeStringValue(aValue), makeIntegerValue(0)},
            aValue);
        checkFunctionResultVarSizes(
            new Value[] {makeStringValue(aValue), makeIntegerValue(-2)},
            aValue);
        checkFunctionResultVarSizes(
            new Value[] {makeStringValue(aValue), makeIntegerValue(3)},
            aValue);
        checkFunctionResultVarSizes(
            new Value[] {
                makeStringValue(aValue), makeIntegerValue(-2), makeStringValue(bValue),
                makeStringValue(cValue)},
            aValue);
        checkFunctionResultVarSizes(
            new Value[] {
                makeStringValue(aValue), makeIntegerValue(2), makeStringValue(bValue),
                makeStringValue(cValue)},
            aValue);
        checkFunctionResultVarSizes(
            new Value[] {
                makeStringValue(aValue), makeIntegerValue(2), makeStringValue(bValue),
                makeStringValue(cValue), makeStringValue(dValue)},
            dValue);
        Value[] params = new Value[DEFAULT_PARAMS_SOFT_LIMIT];
        params[0] = makeStringValue(aValue);
        params[1] = makeIntegerValue(DEFAULT_PARAMS_SOFT_LIMIT - 2 - 1);
        Arrays.fill(params, 2, params.length, makeStringValue(bValue));
        params[DEFAULT_PARAMS_SOFT_LIMIT - 1] = makeStringValue(cValue);
        checkFunctionResultVarSizes(params, cValue);
    }

}
