/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.testutils;

import java.util.HashSet;
import java.util.Set;


/**
 * Helper class grouping simple operations on arrays helpful when writing test cases.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class ArrayTestingUtils {

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private ArrayTestingUtils() { }

    /**
     * Checks whether each element of given array occurs only once, i.e. there're no two
     * equal (as decided by <code>equals</code> method) elements in the array under different
     * indices.
     *
     * @param elements array of elements to check
     * @return <code>true</code> if all array elements are unique, <code>false</code> otherwise
     */
    public static boolean checkUniqueElements(Object[] elements) {
        Set elementsSet = new HashSet();
        for (int i = 0; i < elements.length; i++) {
            elementsSet.add(elements[i]);
        }
        return elementsSet.size() == elements.length;
    }

}
