/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.utils;

import junit.framework.TestCase;


/**
 * Tests for {@link LongFormatter} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestLongFormatter extends TestCase {

    /**
     * Empty default constructor
     */
    public TestLongFormatter() { }

    /**
     * Tests {@link LongFormatter#formatToArray(long, char[], int)} and
     * {@link LongFormatter#getCharactersCount(long)} methods.
     * Calls the method with different buffer sizes, start positions and number values
     * distributed over range of <code>long</code> values. Results are compared with
     * strings returned by <code>Long.toString</code> method.
     */
    public void testFormatToArrayAndGetCharactersCount() {
        // TODO: update for long type
        long[] specialNumbers = {
            Long.MIN_VALUE, -1234567890, -987654321, -23456789,
            -8765432, -345678, -76543, -4567, -654, -56, -5, 0,
            1, 98, 234, 8765, 34567, 765432, 4567890, 65432109, 567890123, Long.MAX_VALUE};
        for (int bufSize = 0; bufSize <= LongFormatter.MAX_CHARACTERS_COUNT * 2; bufSize++) {
            char[] buf = new char[bufSize];
            for (int startPos = 0; startPos <= bufSize; startPos++) {
                for (int i = 0; i < specialNumbers.length; i++) {
                    for (int delta = -10; delta <= 10; delta++) {
                        long value = specialNumbers[i] + delta;
                        String strValue = Long.toString(value);
                        assertEquals(
                            LongFormatter.getCharactersCount(value), strValue.length());
                        int charsCount = LongFormatter.formatToArray(value, buf, startPos);
                        if (startPos + strValue.length() <= bufSize) {
                            assertEquals(charsCount, strValue.length());
                            assertEquals(
                                String.copyValueOf(buf, startPos, charsCount), strValue);
                        } else {
                            assertEquals(charsCount, 0);
                        }
                    }
                }
            }
        }
    }

}
