/*
 * Tests for Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This program is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program; if
 * not, write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
package pl.chyla.wyjec.utils;

import junit.framework.TestCase;


/**
 * Tests for {@link LongUtils} class.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class TestLongUtils extends TestCase {

    /**
     * Empty default constructor
     */
    public TestLongUtils() { }

    /**
     * Tests {@link LongUtils#compare(long, long)} method.
     * Calls the method for selected values, including many border cases.
     */
    public void testCompare() {
        long[] specialValues = {
            Long.MIN_VALUE, -1000000L, -1000L, 0L, 1000L, 1000000L, Long.MAX_VALUE};
        for (int i = 0; i < specialValues.length; i++) {
            for (int j = 0; j < specialValues.length; j++) {
                for (long iDelta = -10L; iDelta <= 10L; iDelta++) {
                    for (long jDelta = -10L; jDelta <= 10L; jDelta++) {
                        long iValue = specialValues[i] + iDelta;
                        long jValue = specialValues[j] + jDelta;
                        if (iValue < jValue) {
                            assertTrue(LongUtils.compare(iValue, jValue) < 0);
                        } else if (iValue > jValue) {
                            assertTrue(LongUtils.compare(iValue, jValue) > 0);
                        } else {
                            assertEquals(LongUtils.compare(iValue, jValue), 0);
                        }
                    }
                }
            }
        }
    }

    /**
     * Tests {@link LongUtils#hashCode(long)} method.
     */
    public void testHashCode() {
        long[] values = {Long.MIN_VALUE, -123456L, -1, 0, 1, 123456L, Long.MAX_VALUE};
        int[] hashCodes = new int[values.length];
        for (int i = 0; i < values.length; i++) {
            hashCodes[i] = LongUtils.hashCode(values[i]);
        }
        for (int i = 0; i < values.length; i++) {
            assertEquals(hashCodes[i], LongUtils.hashCode(values[i]));
        }
    }

}
